gnash-commit
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Gnash-commit] gnash ChangeLog gui/gtk.cpp


From: Benjamin Wolsey
Subject: [Gnash-commit] gnash ChangeLog gui/gtk.cpp
Date: Sat, 26 Apr 2008 19:08:41 +0000

CVSROOT:        /sources/gnash
Module name:    gnash
Changes by:     Benjamin Wolsey <bwy>   08/04/26 19:08:40

Modified files:
        .              : ChangeLog 
        gui            : gtk.cpp 

Log message:
            * gui/gtk.cpp: make the preferences menu buttons more
              intuitive.

CVSWeb URLs:
http://cvs.savannah.gnu.org/viewcvs/gnash/ChangeLog?cvsroot=gnash&r1=1.6408&r2=1.6409
http://cvs.savannah.gnu.org/viewcvs/gnash/gui/gtk.cpp?cvsroot=gnash&r1=1.174&r2=1.175

Patches:
Index: ChangeLog
===================================================================
RCS file: /sources/gnash/gnash/ChangeLog,v
retrieving revision 1.6408
retrieving revision 1.6409
diff -u -b -r1.6408 -r1.6409
--- ChangeLog   26 Apr 2008 18:48:37 -0000      1.6408
+++ ChangeLog   26 Apr 2008 19:08:40 -0000      1.6409
@@ -1,3 +1,8 @@
+2008-04-26 Robert Millan <address@hidden>
+
+    * gui/gtk.cpp: make the preferences menu buttons more
+      intuitive.
+
 2008-04-26 Benjamin Wolsey <address@hidden>
 
        * gui/fb.cpp: do it again, as getenv is not const.

Index: gui/gtk.cpp
===================================================================
RCS file: /sources/gnash/gnash/gui/gtk.cpp,v
retrieving revision 1.174
retrieving revision 1.175
diff -u -b -r1.174 -r1.175
--- gui/gtk.cpp 26 Apr 2008 08:31:19 -0000      1.174
+++ gui/gtk.cpp 26 Apr 2008 19:08:40 -0000      1.175
@@ -920,7 +920,7 @@
 
     prefData *prefs = static_cast<prefData*>(data);
 
-    if (response == GTK_RESPONSE_APPLY) {
+    if (response == GTK_RESPONSE_OK) {
 
         // If 'Save' was clicked, set all the values in rcfile
         RcInitFile& rcfile = RcInitFile::getDefaultInstance();
@@ -995,17 +995,18 @@
        // that instead. How might that best be done?
        rcfile.updateFile();
 
+        // Close the window when 'ok' is clicked
+        gtk_widget_destroy(dialog);
     }
 
-    else if (response == GTK_RESPONSE_CLOSE) {
-        // Close the window only when 'close' is clicked
+    else if (response == GTK_RESPONSE_CANCEL) {
+        // Close the window when 'cancel' is clicked
         gtk_widget_destroy(dialog);
-        if (prefs) delete prefs;
     }
     
-    else if (response == GTK_RESPONSE_DELETE_EVENT) {
+    // response == GTK_RESPONSE_DELETE_EVENT
+
         if (prefs) delete prefs;
-    }
 }
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -1033,8 +1034,8 @@
                                GTK_DIALOG_DESTROY_WITH_PARENT |
                                GTK_DIALOG_NO_SEPARATOR),
                                // The buttons and their response codes:
-                               GTK_STOCK_SAVE, GTK_RESPONSE_APPLY,
-                               GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
+                               GTK_STOCK_OK, GTK_RESPONSE_OK,
+                               GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
                                NULL);
     // Add Gnash icon
     addGnashIcon(GTK_WINDOW(prefsDialog));




reply via email to

[Prev in Thread] Current Thread [Next in Thread]